==> field_manager_python_client-4.4.82rc3.tar.gz: field_manager_python_client-4.4.82rc3/field-manager-python-client/api/files/download_file_projects_project_id_files_file_id_download_get.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.http_validation_error import HTTPValidationError
from ...models.image_size import ImageSize
from ...types import UNSET, Unset
from typing import cast
from typing import cast, Union
from typing import Dict
from typing import Union
from uuid import UUID



def _get_kwargs(
    project_id: str,
    file_id: UUID,
    *,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,

) -> Dict[str, Any]:
    

    

    params: Dict[str, Any] = {}

    json_size: Union[None, Unset, str]
    if isinstance(size, Unset):
        json_size = UNSET
    elif isinstance(size, ImageSize):
        json_size = size.value
    else:
        json_size = size
    params["size"] = json_size

    json_geojson: Union[None, Unset, bool]
    if isinstance(geojson, Unset):
        json_geojson = UNSET
    else:
        json_geojson = geojson
    params["geojson"] = json_geojson


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": "/projects/{project_id}/files/{file_id}/download".format(project_id=project_id,file_id=file_id,),
        "params": params,
    }


    return _kwargs


def _parse_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Optional[Union[Any, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = response.json()
        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())



        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: Union[AuthenticatedClient, Client], response: httpx.Response) -> Response[Union[Any, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,

) -> Response[Union[Any, HTTPValidationError]]:
    """ Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
file_id=file_id,
size=size,
geojson=geojson,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,

) -> Optional[Union[Any, HTTPValidationError]]:
    """ Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
     """


    return sync_detailed(
        project_id=project_id,
file_id=file_id,
client=client,
size=size,
geojson=geojson,

    ).parsed

async def asyncio_detailed(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,

) -> Response[Union[Any, HTTPValidationError]]:
    """ Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
     """


    kwargs = _get_kwargs(
        project_id=project_id,
file_id=file_id,
size=size,
geojson=geojson,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,

) -> Optional[Union[Any, HTTPValidationError]]:
    """ Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
     """


    return (await asyncio_detailed(
        project_id=project_id,
file_id=file_id,
client=client,
size=size,
geojson=geojson,

    )).parsed

==> field_manager_python_client-4.4.90rc6.tar.gz: field_manager_python_client-4.4.90rc6/field-manager-python-client/api/files/download_file_projects_project_id_files_file_id_download_get.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union
from uuid import UUID

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.http_validation_error import HTTPValidationError
from ...models.image_size import ImageSize
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_id: str,
    file_id: UUID,
    *,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,
) -> Dict[str, Any]:
    params: Dict[str, Any] = {}

    json_size: Union[None, Unset, str]
    if isinstance(size, Unset):
        json_size = UNSET
    elif isinstance(size, ImageSize):
        json_size = size.value
    else:
        json_size = size
    params["size"] = json_size

    json_geojson: Union[None, Unset, bool]
    if isinstance(geojson, Unset):
        json_geojson = UNSET
    else:
        json_geojson = geojson
    params["geojson"] = json_geojson

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    _kwargs: Dict[str, Any] = {
        "method": "get",
        "url": f"/projects/{project_id}/files/{file_id}/download",
        "params": params,
    }

    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[Union[Any, HTTPValidationError]]:
    if response.status_code == 200:
        response_200 = response.json()
        return response_200
    if response.status_code == 422:
        response_422 = HTTPValidationError.from_dict(response.json())

        return response_422
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[Union[Any, HTTPValidationError]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,
) -> Response[Union[Any, HTTPValidationError]]:
    """Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        file_id=file_id,
        size=size,
        geojson=geojson,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,
) -> Optional[Union[Any, HTTPValidationError]]:
    """Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
    """

    return sync_detailed(
        project_id=project_id,
        file_id=file_id,
        client=client,
        size=size,
        geojson=geojson,
    ).parsed


async def asyncio_detailed(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,
) -> Response[Union[Any, HTTPValidationError]]:
    """Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, HTTPValidationError]]
    """

    kwargs = _get_kwargs(
        project_id=project_id,
        file_id=file_id,
        size=size,
        geojson=geojson,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_id: str,
    file_id: UUID,
    *,
    client: AuthenticatedClient,
    size: Union[ImageSize, None, Unset] = ImageSize.ORIGINAL,
    geojson: Union[None, Unset, bool] = False,
) -> Optional[Union[Any, HTTPValidationError]]:
    """Download File

     Download the file blob content by project_id and file_id

    Args:
        project_id (str):
        file_id (UUID):
        size (Union[ImageSize, None, Unset]):  Default: ImageSize.ORIGINAL.
        geojson (Union[None, Unset, bool]):  Default: False.

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Union[Any, HTTPValidationError]
    """

    return (
        await asyncio_detailed(
            project_id=project_id,
            file_id=file_id,
            client=client,
            size=size,
            geojson=geojson,
        )
    ).parsed
